@@ -19,7 +19,7 @@ class Client:
             'device_id': deviceID,
             'event_type': event_type,
             'payload': data,
-            'timestamp':  datetime.datetime.now(),
+            'timestamp':  datetime.datetime.now().isoformat(),
         }
         response = requests.post(
             self.endpoint, data=json.dumps(body), headers=headers)
